==> haskell-ixset-typed-0.4.0.1-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ixset-typed
version:              0.4.0.1
visibility:           public
id:                   ixset-typed-0.4.0.1-F9YtVIYY0JIJaejCZqeTMT
key:                  ixset-typed-0.4.0.1-F9YtVIYY0JIJaejCZqeTMT
license:              BSD-3-Clause
maintainer:           Andres Löh <andres@well-typed.com>
author:               Andres Löh, Happstack team, HAppS LLC
synopsis:             Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.

    Sets can be created, modified, and queried in various ways.

    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.

    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.

category:             Data Structures
abi:                  4e779cde3d45aa389ffcd18cb4e20ee4
exposed:              True
exposed-modules:      Data.IxSet.Typed Data.IxSet.Typed.Ix
import-dirs:          /usr/lib/ghc-8.8.3/site-local/ixset-typed-0.4.0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/ixset-typed-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/ixset-typed-0.4.0.1
hs-libraries:         HSixset-typed-0.4.0.1-F9YtVIYY0JIJaejCZqeTMT
depends:
    base-4.13.0.0 containers-0.6.2.1 deepseq-1.4.4.0
    safecopy-0.10.2-GTPq8FmVcbBBzM2OwBwHFF
    syb-0.7.1-HZot41yU46FEB2GjLEhNpM template-haskell-2.15.0.0

haddock-interfaces:   /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html:         /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ixset-typed-0.5-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ixset-typed
version:              0.5
visibility:           public
id:                   ixset-typed-0.5-3DBZ3wxaNbB1mopb63dGa3
key:                  ixset-typed-0.5-3DBZ3wxaNbB1mopb63dGa3
license:              BSD-3-Clause
maintainer:           Andres Löh <andres@well-typed.com>
author:               Andres Löh, Happstack team, HAppS LLC
synopsis:             Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.

    Sets can be created, modified, and queried in various ways.

    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.

    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.

category:             Data Structures
abi:                  802ff173b17bb71847378d542f09f141
exposed:              True
exposed-modules:      Data.IxSet.Typed Data.IxSet.Typed.Ix
import-dirs:          /usr/lib/ghc-8.8.3/site-local/ixset-typed-0.5
library-dirs:         /usr/lib/ghc-8.8.3/site-local/ixset-typed-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/ixset-typed-0.5
hs-libraries:         HSixset-typed-0.5-3DBZ3wxaNbB1mopb63dGa3
depends:
    base-4.13.0.0 containers-0.6.2.1 deepseq-1.4.4.0
    safecopy-0.10.2-5cpsHUGw41hDFvjXhwsBVR
    syb-0.7.1-HZot41yU46FEB2GjLEhNpM template-haskell-2.15.0.0

haddock-interfaces:   /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html:         /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
